pub struct DoubleConfig {
pub config_number: u8,
pub call: String,
pub display: String,
pub tooltip: Option<String>,
pub range: Option<RangeInclusive<f64>>,
pub default_value: f64,
pub group: Option<String>,
}Expand description
This provides a field for entering a numeric value of the given data type. A default value may be provided, as well as a range.
Typically, these configs are created in a lazy_static, and passed to
ConfigStep::list_configs.
Example
use r_extcap::config::*;
let config = DoubleConfig::builder()
.config_number(0)
.call("delay")
.display("Time delay")
.tooltip("Time delay between packages")
.range(-2.6..=8.2)
.default_value(3.3)
.build();
assert_eq!(
format!("{}", ExtcapFormatter(&config)),
"arg {number=0}{call=--delay}{display=Time delay}{tooltip=Time delay between packages}{range=-2.6,8.2}{default=3.3}{type=double}\n"
);Fields
config_number: u8The config number, a unique identifier for this config.
call: StringThe command line option that will be sent to this extcap program. For
example, if this field is foobar, and the corresponding value is 42,
then --foobar 42 will be sent to this program during the extcap
capture.
display: StringThe user-friendly label for the numeric field.
tooltip: Option<String>The tooltip shown on when hovering over the UI element.
range: Option<RangeInclusive<f64>>The valid range of values for this config.
default_value: f64The default value for this config.
group: Option<String>The (user-visible) name of the tab which this config belongs to. If this
is None, the config will be placed in a tab called “Default”.
Implementations
Sourceimpl DoubleConfig
impl DoubleConfig
Sourcepub fn builder() -> DoubleConfigBuilder<((), (), (), (), (), (), ())>
pub fn builder() -> DoubleConfigBuilder<((), (), (), (), (), (), ())>
Create a builder for building DoubleConfig.
On the builder, call .config_number(...), .call(...), .display(...), .tooltip(...)(optional), .range(...)(optional), .default_value(...), .group(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of DoubleConfig.