pub struct PasswordConfig {
pub config_number: u8,
pub call: String,
pub display: String,
pub tooltip: Option<String>,
pub placeholder: Option<String>,
pub required: bool,
pub validation: Option<String>,
pub group: Option<String>,
}Expand description
A field for entering text value, but with its value masked in the user interface. The value of a password field is not saved by Wireshark.
Typically, these configs are created in a lazy_static, and passed to
ConfigStep::list_configs.
Example
use r_extcap::config::*;
let config = PasswordConfig::builder()
.config_number(0)
.call("password")
.display("The user password")
.tooltip("The password for the connection")
.build();
assert_eq!(
format!("{}", ExtcapFormatter(&config)),
"arg {number=0}{call=--password}{display=The user password}{tooltip=The password for the connection}{type=password}\n"
);Fields
config_number: u8The config number, a unique identifier for this config.
call: StringThe command line option that will be sent to this extcap program. For
example, if this field is foobar, and the corresponding value is 42,
then --foobar 42 will be sent to this program during the extcap
capture.
display: StringThe user-friendly label for the password field.
tooltip: Option<String>The tooltip shown on when hovering over the UI element.
placeholder: Option<String>The placeholder string displayed if there is no value in the text field.
required: boolWhether a value is required for this config.
validation: Option<String>A regular expression string used to check the user input for validity.
Despite what the Wireshark documentation says, back-slashes in this
string do not need to be escaped. Just remember to use a Rust raw string
(e.g. r"\d\d\d\d").
group: Option<String>The (user-visible) name of the tab which this config belongs to. If this
is None, the config will be placed in a tab called “Default”.
Implementations
Sourceimpl PasswordConfig
impl PasswordConfig
Sourcepub fn builder() -> PasswordConfigBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> PasswordConfigBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building PasswordConfig.
On the builder, call .config_number(...), .call(...), .display(...), .tooltip(...)(optional), .placeholder(...)(optional), .required(...)(optional), .validation(...)(optional), .group(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PasswordConfig.