ControlCommand

Enum ControlCommand 

#[repr(u8)]
pub enum ControlCommand { Initialized = 0, Set = 1, Add = 2, Remove = 3, Enable = 4, Disable = 5, StatusbarMessage = 6, InformationMessage = 7, WarningMessage = 8, ErrorMessage = 9, }
The control command for the control packet. Note that a ControlCommand is not valid for all control types, for example, the Remove command is applicable only to SelectorControls, and Initialized is only sent by Wireshark to this extcap program.

Variants



Initialized = 0

Sent by Wireshark to indicate that this extcap has been initialized and is ready to accept packets.



Set = 1

Either sent by Wireshark to indicate that the user has interacted with one of the controls, or sent by the extcap program to change the value on a given control.

Used by control types: BooleanControl, ButtonControl, LoggerControl, SelectorControl, and StringControl.



Add = 2

Sent by the extcap program to add a value to the given logger or selector.

Used by control types: LoggerControl and SelectorControl.



Remove = 3

Sent by the extcap program to remove a value from the given selector.

Used by control types: SelectorControl.



Enable = 4

Sent by the extcap program to enable a given control.

Used by control types: BooleanControl, ButtonControl, SelectorControl, and StringControl.



Disable = 5

Sent by the extcap program to disable a given control.

Used by control types: BooleanControl, ButtonControl, SelectorControl, and StringControl.



StatusbarMessage = 6

Sent by the extcap program to show a message in the status bar.



InformationMessage = 7

Sent by the extcap program to show a message in an information dialog popup.



WarningMessage = 8

Sent by the extcap program to show a message in a warning dialog popup.



ErrorMessage = 9

Sent by the extcap program to show a message in an error dialog popup.