pub enum ReloadConfigError {
UnknownConfig(String),
UnsupportedConfig(String),
}Expand description
Error when reloading configs. Config reload happens when a config, like
crate::config::SelectorConfig specifics the reload field and the user
clicks on the created reload button.
Variants
UnknownConfig(String)
The config call value given from Wireshark is not found in the configs
provided. Wireshark makes separate invocations to get the initial list
of interfaces, and when the user subsequently hits reload on a config.
Therefore, implementations should make sure that the configs used in
ConfigStep and ReloadConfigStep are consistent.
UnsupportedConfig(String)
The config given by Wireshark is found, but it is not a
SelectorConfig. This configuration is not expected to be invoked by
Wireshark, as the SelectorConfig::reload field only exists for the
appropriate types.